/*
 * Barcode font:
 * Output text in a barcode font.
 * 
 * Load a barcode font and output text. Enclose the text in the start and stop 
 * characters which are individually defined by the respective barcode font.
 *
 * Required software: PDFlib/PDFlib+PDI/PPS 9
 * Required data: font file
 */
package com.pdflib.cookbook.pdflib.fonts;

import com.pdflib.pdflib;
import com.pdflib.PDFlibException;

public class barcode_font
{
    public static void main (String argv[])
    {
        /* This is where the data files are. Adjust as necessary. */
        String searchpath = "../input";
        String outfile = "barcode_font.pdf";
        String title = "Barcode Font";

        pdflib p = null;
        int normalfont, barcodefont;
        int exitcode = 0;
      
        try {
            p = new pdflib();

            p.set_option("searchpath={" + searchpath + "}");

            /* This means we must check return values of load_font() etc. */
            p.set_option("errorpolicy=return");

            if (p.begin_document(outfile, "") == -1)
                throw new Exception("Error: " + p.get_errmsg());

            p.set_info("Creator", "PDFlib Cookbook");
            p.set_info("Title", title);

            /* Start page */
            p.begin_page_ext(170, 120, "");

            /* Load the barcode font.
             * For a symbol barcode font, please change "unicode" to "builtin".
             */
            barcodefont = p.load_font("FRE3OF9X", "unicode", "embedding");
            if (barcodefont == -1)
                throw new Exception("Error: " + p.get_errmsg());
            
            /* Output text with the barcode font. Note the following when creating
             * barcode text: To create a valid 3 of 9 barcode you have to begin and
             * end it with a special character. Scanners look for this character to
             * know where to start and stop reading the barcode. It is represented
             * in this font with the '*' character. So, to create a barcode for the
             * text "ABC123" you have to type out "*ABC123*". Note that barcode
             * readers will not include the *'s in the text they return. They will
             * just give you the "ABC123".
             */

            p.fit_textline("*ABC123*", 10, 75, "font=" + barcodefont +
                " fontsize=20");
            
            normalfont = p.load_font("NotoSerif-Regular", "unicode", "");
            if (normalfont == -1)
                throw new Exception("Error: " + p.get_errmsg());

            p.fit_textline("*ABC123* ", 10, 60, "font=" + normalfont +
                " fontsize=10");
            p.fit_textline("which will be returned by the", 10, 30, "font=" +
                normalfont + " fontsize=10");
            p.fit_textline("barcode reader as ABC123", 10, 10, "font=" +
                normalfont + " fontsize=10");

            /* Finish page */
            p.end_page_ext("");

            p.end_document("");

        } catch (PDFlibException e) {
            System.err.println("PDFlib exception occurred:");
            System.err.println("[" + e.get_errnum() + "] " + e.get_apiname() +
                                ": " + e.get_errmsg());
            exitcode = 1;
        } catch (Exception e) {
            System.err.println(e);
            exitcode = 1;
        } finally {
            if (p != null) {
                p.delete();
            }
            System.exit(exitcode);
        }
    }
}
