/*
 * PDF/A-1b starter:
 * Create PDF/A-1b conforming output
 *
 * Required software: PDFlib/PDFlib+PDI/PPS 10
 * Required data: font file, image file
 */
package com.pdflib.cookbook.pdflib.pdfa;

import com.pdflib.pdflib;
import com.pdflib.PDFlibException;

public class starter_pdfa1b {
    public static void main(String argv[]) {
        /* This is where the data files are. Adjust as necessary. */
        String searchpath = "../input";
        String outfile = "starter_pdfa1b.pdf";
        String title = "Starter PDF/A";

        pdflib p = null;
        String imagefile = "nesrin.jpg";

        int exitcode = 0;
        int image;

        try {
            p = new pdflib();
            
            // Make sure we are using an appropriate PDFlib version
            if ((int) p.get_option("major", "") < 10) {
                System.err.println("Error: Cookbook topic '" + title + "' requires PDFlib 10");
                System.exit(1);
            }

            p.set_option("searchpath={" + searchpath + "}");

            /* This means we must check return values of load_font() etc. */
            p.set_option("errorpolicy=return");

            /* PDF/A-1a requires Tagged PDF */
            if (p.begin_document(outfile, "pdfa=PDF/A-1b:2005") == -1)
                throw new Exception("Error: " + p.get_errmsg());

            p.set_info("Creator", "PDFlib Cookbook");
            p.set_info("Title", title);

            p.begin_page_ext(0, 0, "width=a4.width height=a4.height");

            p.fit_textline("PDF/A-1b:2005 starter", 50, 700, "fontname=NotoSerif-Regular fontsize=24");

            /* Load an RGB image */
            image = p.load_image("auto", imagefile, "");

            if (image == -1)
                throw new Exception("Error: " + p.get_errmsg());

            /* Place the image at the bottom of the page */
            p.fit_image(image, 0.0, 0.0, "scale=0.5");

            p.end_page_ext("");
            p.close_image(image);

            p.end_document("");

        }
        catch (PDFlibException e) {
            System.err.println("PDFlib exception occurred:");
            System.err.println("[" + e.get_errnum() + "] " + e.get_apiname() +
                ": " + e.get_errmsg());
            exitcode = 1;
        }
        catch (Exception e) {
            System.err.println(e);
            exitcode = 1;
        }
        finally {
            if (p != null) {
                p.delete();
            }
            System.exit(exitcode);
        }
    }
}
